@@ -86,7 +86,7 @@ load_configuration (ConduitCfg **c,guint32 pilotId)
 
 	(*c)->dir = gnome_config_get_string ("dir=");
 	
-	while ((*c)->dir[strlen ((*c)->dir)-1] == '/') {
+	while ((*c)->dir && strlen ((*c)->dir) > 0 && (*c)->dir[strlen ((*c)->dir)-1] == '/') {
 		(*c)->dir[strlen ((*c)->dir)-1] = '\0';
 	}
 	
@@ -1325,7 +1325,7 @@ readOptionsCfg (GtkWidget *pilotcfg, ConduitCfg *state)
 	if (state->dir) g_free (state->dir);
 	state->dir = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
 
-	while (state->dir[strlen (state->dir)-1] == '/') {
+	while (state->dir && strlen (state->dir) > 0 && state->dir[strlen (state->dir)-1] == '/') {
 		state->dir[strlen (state->dir)-1] = '\0';
 	}
 
